# Scientometric

Note: This document is currently under development. It will contain the following elements.

## Short summary

- explanation
- goals
- dimensions
- differences between disciplines

For the analysis of citation data, established software packages like [VosViewer](https://www.vosviewer.com/) are recommended.

## Steps and operations

### Problem formulation

### Metadata retrieval

### Metadata prescreen

### PDF retrieval

### PDF screen

### Data extraction and synthesis

- For manuscript development see separate page for Word/Tex/Md, Reference Managers

## Software recommendations

## References
